package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````8)P$"#0```"PPP```````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(1+,`
M`$2S```%`````!````$```#DO@``Y$X%".1.!0AT`@``S!(```8`````$```
M`@```/B^``#X3@4(^$X%"/@```#X````!@````0````$````2`$``$B!!`A(
M@00((````"`````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9.2^``#D3@4(Y$X%"!P!```<`0``!`````$````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````/````
M80```',````+``````````````!#`````````$@```!'``````````````!:
M````/@```#D```!+````!````%@`````````,0```%\```!5````:@```&P`
M``!G````!0```"P``````````````"H```!C````1@``````````````9```
M`$D```!E````"0````````!2````<@````(```!-`````````!\`````````
M<`````````!1````;@``````````````9@```"@```!/````.@``````````
M````;P```#4```!`````10``````````````$P`````````_````````````
M```C`````````!P````P````#````#(````I````5```````````````6P``
M`%`````\````7@```$P````[````-``````````-````````````````````
M5@```&T`````````1````%T```!"````/0```"<````!````````````````
M`````````````````````````````````````````````````````````$X`
M``````````````````````````````\`````````$````!4```!@````````
M````````````%```````````````$@`````````9````````````````````
M`````%D`````````5P````````!H```````````````1````````````````
M````&P`````````F````:0```"0````(`````````"\````E````#@```!T`
M````````80```"$`````````&@````H``````````````$$`````````,P``
M`!X````N`````````'$```!<`````````$H````'``````````````!K````
M````````````````````````````````(@``````````````&``````````V
M`````````"L`````````````````````````%P`````````6`````````%,`
M````````!@```````````````````&(````W`````P```"`````M````.```
M`"4```!.````"`````@`````$!`$)4`$@*@1``&BAD&H0````DLH!"DXHC)'
MB@0,B$X```!0````````````````````4P```%4```!6`````````%<```!8
M`````````%D```!:````6P````````!<````````````````````70```&``
M`````````````&$```!C````9````&8`````````:````&L`````````;0``
M`&X```!O````<`````````#(U;)Q6>CM[.;_,*+.WD<MH^#[2>K3[PZGW:-K
M+\6;MMO-XYZ'^9R!:PE#U@TZEPO%B060#13BGB'_Y`ZR`8MOQ+F<0&M_FGQ_
MJ9R;;L7?']EQ6!R[XY)\U&34?*U+X\`R8MOMX:<""F:OS&9@%LE9>_!*:^)'
MQ@%#1=7L1^PS.GU!CL7#Y3\L\MO3'?JA;&"YC?$.````````````````````
M`/@"`````````````!(```!&`P`````````````2````L0``````````````
M$@```)0#`````````````!(```!_`P`````````````2````H0$`````````
M````$@```'H"`````````````!(````1```````````````@````(```````
M````````(````(4#`````````````!(```"-`0`````````````2````-`0`
M````````````$@```&X!`````````````!(```"``0`````````````2````
M7P,`````````````$@```"\#`````````````!(````)`P`````````````2
M````+`(`````````````$@```/T``````````````!(````<`@``````````
M```2````L`,`````````````$@```,H!`````````````!(````8!```````
M```````2````UP(`````````````$@```!$#`````````````!(```"8`@``
M```````````2````Z@$`````````````$@```*8!`````````````!(````U
M`@`````````````2````/@0`````````````$@````H$`````````````!(`
M```O`0`````````````2````RP,`````````````$@```#0`````````````
M`!(```#3`P`````````````2````70$`````````````$@```,@`````````
M`````!(```#X`P`````````````2````Q`,`````````````$@```/$#````
M`````````!(```"I`P`````````````2````>`,`````````````$@```/P$
M`````````````!(```!!`0`````````````2````X0,`````````````$@``
M`%P"`````````````!(```!6`P`````````````2````ZP(`````````````
M$@```$X"`````````````!(```"W`P`````````````2````D0(`````````
M````$@```*L!`````````````!(```!G`P`````````````2````O@,`````
M````````$@```*(#`````````````!(```#L```````````````2````0@``
M````````````$@```.@#`````````````!(````"!``````````````2````
MUP``````````````$@```/X!`````````````!(```"%`@`````````````2
M````4`$`````````````$@```(T#`````````````!(```!.`P``````````
M```2````\0(`````````````$@```!T!`````````````!(```!#`@``````
M```````2````5```````````````$@```)L#`````````````!(```#8`0``
M```````````2````8P``````````````$@```!$$`````````````!(```"/
M```````````````2````00,`````````````$@```'@``````````````!(`
M```+`0`````````````2````MP$``-R7!`@`````$@```)T$``#@V`0(!```
M`!$`#P!F!0``X-L$"%U7```1``\`<`4``&C"!`BN!P``$@`-`)P%```=IP0(
M]0$``!(`#0"7!```N-@$"``````2``X`+`0``&!1!0@$````(0`8`&\$``#/
MH@0(#0```!(`#0`U!0``T-<$"%P````2``T`H````*R9!`@`````$@```"`%
M```\404(`````!``%P`B!0``/%$%"``````@`!<`*P0``&!1!0@$````(0`8
M`(T$``#`UP0(!0```!(`#0"/!0``W*($"-D"```2``T`N@0``!*I!`A:````
M$@`-`"H$``!@404(!````!$`&``E!```C]0$"`$#```2``T`Z@0``"C`!`@[
M````$@`-``4%``"%RP0(90```!(`#0!>!```6%$%"``````0`/'_:@0``+!A
M!0@`````$`#Q_Z0$```>SP0(!04``!(`#0`@`P``Y-@$"`0````1``\`)@4`
M`&"<!`@`````$@`-`,@$``"ZH00(%0$``!(`#0#>!```\:4$""P!```2``T`
M$04``%11!0@$````$0`7`&H"``"<F00(`````!(```"`!```M:4$"#P````2
M``T`5P0``%A1!0@`````$`#Q_V$%``!0404(!````!$`%P!%!0``O\X$"%\`
M```2``T`+04``!B=!`A`````$@`-`*,"``!D404($P```!$`&`!]!0``/,$$
M""P!```2``T`+P4``"R7!`@`````$@`+``!L:6)P97)L+G-O+C4N,3``7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M
M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?
M9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V
M7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`
M<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R
M<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N
M`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?
M<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?
M27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!0
M97)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L
M+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S<')I;G1F`'-T<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`7V9P7VAW`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?7V1A=&%?<W1A<G0`
M>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!
M4E-404-+`&YA;65?;&]A9%]M95\R`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'
M3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,``````"
M``,````#``,````````````#````!````````P`%``8``````````P````,`
M`@`"```````#````!``#`````P````<```````0``P`#``,``P`#`````P``
M``,``@````,``P````@``P`#```````#``,````````````#``,`!@``````
M```#```````#`````P`````````!``$``0`!``$``P`!``$````!``$``P`!
M``$``0`#``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0````$`
M`0`!``4`%@,``!````!@````%&EI#0``"`"I!0``$````!-I:0T```<`LP4`
M`!````!R&6D)```%`+T%```0````$FEI#0``!`#)!0``$````!!I:0T```,`
MTP4````````!``(`QP(``!``````````$FEI#0``!@#)!0``$````!!I:0T`
M``(`TP4```````#P3P4(!@@``&!1!0@%7@``9%$%"`5P````4`4(!P$```10
M!0@'`@``"%`%"`<#```,4`4(!P0``!!0!0@'!0``%%`%"`<&```84`4(!P<`
M`!Q0!0@'3@``(%`%"`<(```D4`4(!PH``"A0!0@'"P``+%`%"`<,```P4`4(
M!PT``#10!0@'#@``.%`%"`</```\4`4(!Q```$!0!0@'$0``1%`%"`<2``!(
M4`4(!Q,``$Q0!0@'%```4%`%"`<5``!44`4(!Q8``%A0!0@'%P``7%`%"`<8
M``!@4`4(!QD``&10!0@'&@``:%`%"`<;``!L4`4(!QP``'!0!0@''0``=%`%
M"`<>``!X4`4(!Q\``'Q0!0@'(```@%`%"`<A``"$4`4(!R(``(A0!0@'(P``
MC%`%"`=J``"04`4(!U<``)10!0@')```F%`%"`<E``"<4`4(!R8``*!0!0@'
M)P``I%`%"`<H``"H4`4(!RD``*Q0!0@'*@``L%`%"`<K``"T4`4(!RP``+A0
M!0@'+0``O%`%"`<N``#`4`4(!R\``,10!0@',```R%`%"`<Q``#,4`4(!S(`
M`-!0!0@',P``U%`%"`<T``#84`4(!S4``-Q0!0@'-@``X%`%"`<W``#D4`4(
M!S@``.A0!0@'.0``[%`%"`<Z``#P4`4(!SL``/10!0@'/```^%`%"`<]``#\
M4`4(!SX```!1!0@'/P``!%$%"`=````(404(!T$```Q1!0@'0@``$%$%"`=#
M```4404(!T0``!A1!0@'10``'%$%"`=&```@404(!T<``"11!0@'2```*%$%
M"`=)```L404(!TH``#!1!0@'2P``-%$%"`=,```X404(!TT``%6)Y5.#[`3H
M`````%N!P[RX``"+D_S___^%TG0%Z)X```#HG04``.@X00``6%O)P_\U^$\%
M"/\E_$\%"`````#_)0!0!0AH`````.G@_____R4$4`4(:`@```#IT/____\E
M"%`%"&@0````Z<#_____)0Q0!0AH&````.FP_____R404`4(:"````#IH/__
M__\E%%`%"&@H````Z9#_____)1A0!0AH,````.F`_____R4<4`4(:#@```#I
M</____\E(%`%"&A`````Z6#_____)210!0AH2````.E0_____R4H4`4(:%``
M``#I0/____\E+%`%"&A8````Z3#_____)3!0!0AH8````.D@_____R4T4`4(
M:&@```#I$/____\E.%`%"&AP````Z0#_____)3Q0!0AH>````.GP_O___R5`
M4`4(:(````#IX/[___\E1%`%"&B(````Z=#^____)4A0!0AHD````.G`_O__
M_R5,4`4(:)@```#IL/[___\E4%`%"&B@````Z:#^____)510!0AHJ````.F0
M_O___R584`4(:+````#I@/[___\E7%`%"&BX````Z7#^____)6!0!0AHP```
M`.E@_O___R5D4`4(:,@```#I4/[___\E:%`%"&C0````Z4#^____)6Q0!0AH
MV````.DP_O___R5P4`4(:.````#I(/[___\E=%`%"&CH````Z1#^____)7A0
M!0AH\````.D`_O___R5\4`4(:/@```#I\/W___\E@%`%"&@``0``Z>#]____
M)810!0AH"`$``.G0_?___R6(4`4(:!`!``#IP/W___\EC%`%"&@8`0``Z;#]
M____)9!0!0AH(`$``.F@_?___R644`4(:"@!``#ID/W___\EF%`%"&@P`0``
MZ8#]____)9Q0!0AH.`$``.EP_?___R6@4`4(:$`!``#I8/W___\EI%`%"&A(
M`0``Z5#]____):A0!0AH4`$``.E`_?___R6L4`4(:%@!``#I,/W___\EL%`%
M"&A@`0``Z2#]____);10!0AH:`$``.D0_?___R6X4`4(:'`!``#I`/W___\E
MO%`%"&AX`0``Z?#\____)<!0!0AH@`$``.G@_/___R7$4`4(:(@!``#IT/S_
M__\ER%`%"&B0`0``Z<#\____)<Q0!0AHF`$``.FP_/___R704`4(:*`!``#I
MH/S___\EU%`%"&BH`0``Z9#\____)=A0!0AHL`$``.F`_/___R7<4`4(:+@!
M``#I</S___\EX%`%"&C``0``Z6#\____)>10!0AHR`$``.E0_/___R7H4`4(
M:-`!``#I0/S___\E[%`%"&C8`0``Z3#\____)?!0!0AHX`$``.D@_/___R7T
M4`4(:.@!``#I$/S___\E^%`%"&CP`0``Z0#\____)?Q0!0AH^`$``.GP^___
M_R4`404(:``"``#IX/O___\E!%$%"&@(`@``Z=#[____)0A1!0AH$`(``.G`
M^____R4,404(:!@"``#IL/O___\E$%$%"&@@`@``Z:#[____)111!0AH*`(`
M`.F0^____R48404(:#`"``#I@/O___\E'%$%"&@X`@``Z7#[____)2!1!0AH
M0`(``.E@^____R4D404(:$@"``#I4/O___\E*%$%"&A0`@``Z4#[____)2Q1
M!0AH6`(``.DP^____R4P404(:&`"``#I(/O___\E-%$%"&AH`@``Z1#[____
M)3A1!0AH<`(``.D`^___`````#'M7HGA@^3P4%12:,#7!`AHT-<$"%%6:(_4
M!`CH2_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/7A1!0@`=4"X\$X%"(L5
M?%$%""WL3@4(P?@"C5C_.=IS'XVV`````(U"`:-\404(_Q2%[$X%"(L5?%$%
M"#G:<N?&!7A1!0@!6%M=PXVV`````(V_`````%6)Y8/L"(L5]$X%"(72=!:X
M`````(7`=`V#[`QH]$X%"/_0@\00R<-5B>6#[!C'1?SHV`0(@^P,:@#HO?[_
M_X/$$(L`@^P,4.B?^___@\00_W7\:)R9!`AH\M@$"%#H:?[__X/$$,G#58GE
M4X'L)!```(M%#(F%Z.___XM%$(F%Y.___V6A%````(E%^#'`@^P$:/\/``"-
MA?CO__]0:`[9!`CHA/W__X/$$(F%].___X.]].___P!^&(N%].___TB*A`7X
M[___A,!U!O^-].___X.]].___P!^6XN%].___X/L!%!J+XV%^.___U#HF?W_
M_X/$$(7`=#R+G?3O__^#[`QJ`.CR_?__@\00BP"#[`Q0Z-3Z__^#Q!")PE.-
MA?CO__]0_[7H[___4N@;_/__@\00ZS.#[`QJ`.B\_?__@\00BP"#[`Q0Z)[Z
M__^#Q!"#[`3_M>3O____M>CO__]0Z&;Z__^#Q!"+1?AE,P44````=`7H8OS_
M_XM=_,G#58GE@^P8@WT(`'0)H6!1!0B%P'4,QT7L`````.F8````BT4(B47T
MZP/_1?2+5?2*`H3`=`F+3?2*`3P]=>N+5?2+10B)T2G!B4WPH6!1!0B)1?CK
M3XM%\(/L!%#_=0C_=?SHMOS__X/$$(7`=3*+1?`#1?R*`#P]=2:+5?BA8%$%
M"(G1*<&)R,'X`HG"BT4,B1"+1?!`BU7\`<*)5>SK&8-%^`2+3?B+"8E-_(-]
M_`!UH\=%[`````"+1>S)PU6)Y8/L&(/L"(U%_%#_=0CH+?___X/$$,G#58GE
M4X/L)(M5#(H"/#UU`_]%#(/L#/]U#.BG^O__@\00B47X@^P(C47T4/]U".CU
M_O__@\00B47@@WW@`'1!@^P,_W7@Z'OZ__^#Q!`[1?@/@O\```"+30R*`8M5
MX(@"BTW@B@&$P`^5P/]%X/]%#(3`=>+'1=P`````Z9X!``"A8%$%"(E%Z,=%
MY`````#K!X-%Z`3_1>2+5>B+`H7`=?"A@%$%"(7`=#:+1>2#P`+!X`*+%6!1
M!0B#[`A04NCR]___@\00HV!1!0BA8%$%"(7`=67'1=S_____Z3X!``#'!8!1
M!0@!````BT7D@\`"P>`"@^P,4.AI^O__@\00B47H@WWH`'4,QT7<_____^D*
M`0``BT7DP>`"BQ5@404(@^P$4%+_=>CHN/K__X/$$(M-Z(D-8%$%"(L58%$%
M"(M%Y$#!X`*-!`+'``````"+1>2)1?2+10B)1>#K`_]%X(M5X(H"A,!T"8M-
MX(H!/#UUZXL58%$%"(M%],'@`HT<`HM5X(M%"(G1*<&)R`-%^(/``H/L#%#H
MR?G__X/$$(D#BP.%P'4)QT7<_____^MNBQ5@404(BT7TP>`"C00"BP")1>#K
M`_]%X(M%"(H`BU7@B`*+3>"*`83`#Y7`_T4(@_`!A,!U"8M5X(H"/#UUUHM-
MX,8!/?]%X(M5#(H"BTW@B`&+5>"*`H3`#Y7`_T7@_T4,A,!UXL=%W`````"+
M1=R+7?S)PU6)Y8/L&.LMBQ5@404(BT7\P>`"`<*)5>R+1>R#P`2+`(M5[(D"
MBU7LBP*%P'0&@T7L!.OD@^P(C47\4/]U".B^_/__@\00A<!UO<G#58GE@>P8
M(```9:$4````B47\,<#'A?3?__\`````Z+_U__]H(=D$"%!H)=D$"(V%^^__
M_U#HB/7__X/$$(F%\-___X.]\-___P!Y#\>%[-___P````#IH0```(/L!&@`
M$```C87ZW___4(V%^^___U#H[/C__X/$$(F%\-___X.]\-___P!Y#,>%[-__
M_P````#K:(N%\-___T"#[`Q0Z$[X__^#Q!")A?3?__^#O?3?__\`=0S'A>S?
M__\`````ZSJ+A?#?__^#[`10C87ZW___4/^U]-___^A4]___@\00BX7PW___
M`X7TW___Q@``BY7TW___B97LW___BX7LW___BU7\93,5%````'0%Z/_W___)
MPU6)Y8/L".C@_O__R<-5B>6![#@0``"+10B)A=SO__^+10R)A=CO__]EH10`
M``")1?PQP(/L#&@QV00(Z![\__^#Q!")A>SO__^A1%$%"(/L"%#_M=SO___H
M</?__X/$$(7`=">#[`C_M=SO__]H.MD$".@!_/__@\00BY7<[___B974[___
MZ4("``"#[`S_M=SO___HI/;__X/$$(F%].___Z%(404(@^P(4/^UV.___^AG
M]___@\00B87X[___Z=H!``"+A?CO__^*`(3`=0K'A?CO__]'V00(@[WL[___
M`'0Y@^P(_[7X[____[7L[___Z$;X__^#Q!"%P'4>H4A1!0B#[`A0:@#H#_?_
M_X/$$(F%^.___^F"`0``@^P,_[7X[___Z!/V__^#Q!")A?#O___K%?^-\.__
M_XN%\.___P.%^.___\8``(N%\.___T@#A?CO__^*$*%$404(B@`XPG31BX7P
M[___0`.%].___SW_#P``?B>#[`C_M=SO__]H.MD$".CM^O__@\00BX7<[___
MB874[___Z2X!``"A1%$%"(/L#/^UW.___U#_M?CO__]H2=D$"(V%_.___U#H
MZ/+__X/$((/L#&H`Z$OW__^#Q!"+`(/L#%#H+?3__X/$$(/L#%#H4?;__X/$
M$(/L"%"-A?SO__]0Z&(S``"#Q!"%P'5_@^P,:@#H#??__X/$$(L`@^P,4.CO
M\___@\00@^P,4.@3]O__@\00BT`0)0#P```]`(```'5)@^P(:@&-A?SO__]0
MZ##T__^#Q!"%P'4Q@^P(C87\[___4&@ZV00(Z!#Z__^#Q!"#[`R-A?SO__]0
MZ)/V__^#Q!")A=3O___K2*%(404(@^P(4&H`Z(CU__^#Q!")A?CO__^#O?CO
M__\`#X49_O__@^P(_[7<[___:#K9!`CHNOG__X/$$(N5W.___XF5U.___XN%
MU.___XM5_&4S%10```!T!>@9]?__R<-5B>6#[!"+10B)1?R+10B)1?CK&HM%
M^(H0H411!0B*`#C"=0>+1?A`B47\_T7XBT7XB@"$P'7=BT7\R<-5B>6#[`B#
M?0@`=`F+10B*`(3`=1B#[`QH1]D$".C)]?__@\00B47XZ?H```"#[`S_=0CH
MX_/__X/$$$B+50@!PHE5_.L#_TW\BTW\.TT(=A:+5?R*`HL51%$%"(H2.-!T
MY.L#_TW\BTW\.TT(=A&+5?R*`HL51%$%"(H2.-!UY(M-_#M-"'4\BU7\B@*+
M%411!0B*$CC0=16#[`QH1]D$".A%]?__@\00B47XZWFA1%$%"(/L#%#H+_7_
M_X/$$(E%^.MC_TW\BTW\.TT(=A&+5?R*`HL51%$%"(H2.-!TY(M5_(M%"(G1
M*<&)R(/``CT`$```=@G'1?@`````ZRB+5?R+10B)T2G!B<A`@^P$4/]U"&B@
M404(Z#[Q__^#Q!#'1?B@404(BT7XR<-5B>575H/L0&6A%````(E%]#'`C572
MB57$QT7`_-D$",=%O`@```"+?<2+=<"+3;SSI8EUP(E]Q(M5P(L"BTW$9HD!
M@T7$`H-%P`*#[`QH4-D$".CX^?__@\00@^P,:&#9!`CHZ/G__X/$$(/L#&@Q
MV00(Z-CY__^#Q!"#[`QH;-D$".C(^?__@\00@^P,:';9!`CHN/G__X/$$(/L
M#&B`V00(Z*CY__^#Q!"#[`QH.MD$".B8^?__@\00@^P,:(K9!`CHB/G__X/$
M$(/L#&B3V00(Z'CY__^#Q!"#[`QHGMD$".@H]___@\00B47,@WW,`'03@^P(
M_W7,:';9!`CH)O?__X/$$(/L#&BOV00(Z/SV__^#Q!")1<R#?<P`=!.#[`C_
M=<QHP=D$".CZ]O__@\00@^P,:,S9!`CHT/;__X/$$(E%S(-]S`!T%8/L"/]U
MS&@QV00(Z,[V__^#Q!#K9X/L#&C<V00(Z*+V__^#Q!")1<R#?<P`=!6#[`C_
M=<QH;-D$".B@]O__@\00ZSF-1=*#P!&)1<R#[`1J"FCMV00(_W7,Z,7R__^#
MQ!"%P'47BT7,@\`*@^P(4&ALV00(Z&7V__^#Q!"#[`AH^-D$"&A0V00(Z%#V
M__^#Q!"+=?1E,S44````=`7HP?'__XUE^%Y?7<-5B>6#[!BA3%$%"(/X_W5#
M@^P,:&S9!`CH_O7__X/$$(E%_(-]_`!T&XM%_(H`A,!T$HM%_(H`/#!T"<=%
M[`$```#K!\=%[`````"+1>RC3%$%"*%,404(R<-5B>53@>QP`0``BT4(@\`<
MB47TQT7X`````.M#BT7TBP")1?"#1?0$BTWXBT7PB<+!XAB+1?#!X`@E``#_
M``G"BT7PP>@()0#_```)PHM%\,'H&`G0B82-F/[___]%^(-]^`]^M\=%^!``
M``#K7HM-^(M%^(/H`XN4A9C^__^+1?B#Z`B+A(68_O__,<*+1?B#Z`Z+A(68
M_O__,<*+1?B#Z!"+A(68_O__,=")A(V8_O__BU7XBT7XBX2%F/[__\'('XF$
ME9C^____1?B#??A/?IR+10B+`(E%[(M%"(M`!(E%Z(M%"(M`"(E%Y(M%"(M`
M#(E%X(M%"(M`$(E%W(V%F/[__XE%V(M%[(G!P<D;BU7DBT7H(<*+1>CWT"-%
MX`G0C00!B<(#5=R+1=B+`(T$`@69>8):B47P@T78!,%-Z`*+1?")P<')&XM5
MZ(M%["'"BT7L]]`C1>0)T(T$`8G"`U7@BT78BP"-!`(%F7F"6HE%W(-%V`3!
M3>P"BT7<B<'!R1N+5>R+1?`APHM%\/?0(T7H"="-!`&)P@-5Y(M%V(L`C00"
M!9EY@EJ)1>"#1=@$P4WP`HM%X(G!P<D;BU7PBT7<(<*+1=SWT"-%[`G0C00!
MB<(#5>B+1=B+`(T$`@69>8):B47D@T78!,%-W`*+1>2)P<')&XM5W(M%X"'"
MBT7@]]`C1?`)T(T$`8G"`U7LBT78BP"-!`(%F7F"6HE%Z(-%V`3!3>`"BT7H
MB<'!R1N+5>"+1>0APHM%Y/?0(T7<"="-!`&)P@-5\(M%V(L`C00"!9EY@EJ)
M1>R#1=@$P4WD`HM%[(G!P<D;BU7DBT7H(<*+1>CWT"-%X`G0C00!B<(#5=R+
M1=B+`(T$`@69>8):B47P@T78!,%-Z`*+1?")P<')&XM5Z(M%["'"BT7L]]`C
M1>0)T(T$`8G"`U7@BT78BP"-!`(%F7F"6HE%W(-%V`3!3>P"BT7<B<'!R1N+
M5>R+1?`APHM%\/?0(T7H"="-!`&)P@-5Y(M%V(L`C00"!9EY@EJ)1>"#1=@$
MP4WP`HM%X(G!P<D;BU7PBT7<(<*+1=SWT"-%[`G0C00!B<(#5>B+1=B+`(T$
M`@69>8):B47D@T78!,%-W`*+1>2)P<')&XM5W(M%X"'"BT7@]]`C1?`)T(T$
M`8G"`U7LBT78BP"-!`(%F7F"6HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0A
MPHM%Y/?0(T7<"="-!`&)P@-5\(M%V(L`C00"!9EY@EJ)1>R#1=@$P4WD`HM%
M[(G!P<D;BU7DBT7H(<*+1>CWT"-%X`G0C00!B<(#5=R+1=B+`(T$`@69>8):
MB47P@T78!,%-Z`*+1?")P<')&XM5Z(M%["'"BT7L]]`C1>0)T(T$`8G"`U7@
MBT78BP"-!`(%F7F"6HE%W(-%V`3!3>P"BT7<B<'!R1N+5>R+1?`APHM%\/?0
M(T7H"="-!`&)P@-5Y(M%V(L`C00"!9EY@EJ)1>"#1=@$P4WP`HM%X(G!P<D;
MBU7PBT7<(<*+1=SWT"-%[`G0C00!B<(#5>B+1=B+`(T$`@69>8):B47D@T78
M!,%-W`*+1>2)P<')&XM5W(M%X"'"BT7@]]`C1?`)T(T$`8G"`U7LBT78BP"-
M!`(%F7F"6HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0APHM%Y/?0(T7<"="-
M!`&)P@-5\(M%V(L`C00"!9EY@EJ)1>R#1=@$P4WD`HM%[(G!P<D;BU7DBT7H
M(<*+1>CWT"-%X`G0C00!B<(#5=R+1=B+`(T$`@69>8):B47P@T78!,%-Z`*+
M1?")P<')&XM5Z(M%["'"BT7L]]`C1>0)T(T$`8G"`U7@BT78BP"-!`(%F7F"
M6HE%W(-%V`3!3>P"BT7<B<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-
M!`(%H>O9;HE%X(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7H
MBT78BP"-!`(%H>O9;HE%Y(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$
M`8G"`U7LBT78BP"-!`(%H>O9;HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0Q
MT#-%W(T$`8G"`U7PBT78BP"-!`(%H>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+
M5>2+1>@QT#-%X(T$`8G"`U7<BT78BP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7P
MB<'!R1N+5>B+1>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!
M3>P"BT7<B<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%
MX(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%
MH>O9;HE%Y(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78
MBP"-!`(%H>O9;HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"
M`U7PBT78BP"-!`(%H>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%
MX(T$`8G"`U7<BT78BP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7PB<'!R1N+5>B+
M1>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!3>P"BT7<B<'!
MR1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%X(-%V`3!3?`"
MBT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%H>O9;HE%Y(-%
MV`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78BP"-!`(%H>O9
M;HE%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"`U7PBT78BP"-
M!`(%H>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%X(T$`8G"`U7<
MBT78BP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7PB<'!R1N+5>B+1>PQT#-%Y(T$
M`8G"`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!3>P"BT7<B<'!R1N+5>R+1?`Q
MT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%X(-%V`3!3?`"BT7@B<'!R1N+
M5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%H>O9;HE%Y(-%V`3!3=P"BT7D
MB</!RQN+5?"+1=P)T(G!(TW@BU7PBT7<(=`)R(T$`XG"`U7LBT78BP"-!`(M
M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+5=R+1>`)T(G!(TWDBU7<BT7@(=`)
MR(T$`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!3>0"BT7LB</!RQN+5>"+
M1>0)T(G!(TWHBU7@BT7D(=`)R(T$`XG"`U7<BT78BP"-!`(M)$/D<(E%\(-%
MV`3!3>@"BT7PB</!RQN+5>2+1>@)T(G!(TWLBU7DBT7H(=`)R(T$`XG"`U7@
MBT78BP"-!`(M)$/D<(E%W(-%V`3!3>P"BT7<B</!RQN+5>B+1>P)T(G!(TWP
MBU7HBT7L(=`)R(T$`XG"`U7DBT78BP"-!`(M)$/D<(E%X(-%V`3!3?`"BT7@
MB</!RQN+5>R+1?`)T(G!(TW<BU7LBT7P(=`)R(T$`XG"`U7HBT78BP"-!`(M
M)$/D<(E%Y(-%V`3!3=P"BT7DB</!RQN+5?"+1=P)T(G!(TW@BU7PBT7<(=`)
MR(T$`XG"`U7LBT78BP"-!`(M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+5=R+
M1>`)T(G!(TWDBU7<BT7@(=`)R(T$`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%
MV`3!3>0"BT7LB</!RQN+5>"+1>0)T(G!(TWHBU7@BT7D(=`)R(T$`XG"`U7<
MBT78BP"-!`(M)$/D<(E%\(-%V`3!3>@"BT7PB</!RQN+5>2+1>@)T(G!(TWL
MBU7DBT7H(=`)R(T$`XG"`U7@BT78BP"-!`(M)$/D<(E%W(-%V`3!3>P"BT7<
MB</!RQN+5>B+1>P)T(G!(TWPBU7HBT7L(=`)R(T$`XG"`U7DBT78BP"-!`(M
M)$/D<(E%X(-%V`3!3?`"BT7@B</!RQN+5>R+1?`)T(G!(TW<BU7LBT7P(=`)
MR(T$`XG"`U7HBT78BP"-!`(M)$/D<(E%Y(-%V`3!3=P"BT7DB</!RQN+5?"+
M1=P)T(G!(TW@BU7PBT7<(=`)R(T$`XG"`U7LBT78BP"-!`(M)$/D<(E%Z(-%
MV`3!3>`"BT7HB</!RQN+5=R+1>`)T(G!(TWDBU7<BT7@(=`)R(T$`XG"`U7P
MBT78BP"-!`(M)$/D<(E%[(-%V`3!3>0"BT7LB</!RQN+5>"+1>0)T(G!(TWH
MBU7@BT7D(=`)R(T$`XG"`U7<BT78BP"-!`(M)$/D<(E%\(-%V`3!3>@"BT7P
MB</!RQN+5>2+1>@)T(G!(TWLBU7DBT7H(=`)R(T$`XG"`U7@BT78BP"-!`(M
M)$/D<(E%W(-%V`3!3>P"BT7<B</!RQN+5>B+1>P)T(G!(TWPBU7HBT7L(=`)
MR(T$`XG"`U7DBT78BP"-!`(M)$/D<(E%X(-%V`3!3?`"BT7@B</!RQN+5>R+
M1?`)T(G!(TW<BU7LBT7P(=`)R(T$`XG"`U7HBT78BP"-!`(M)$/D<(E%Y(-%
MV`3!3=P"BT7DB</!RQN+5?"+1=P)T(G!(TW@BU7PBT7<(=`)R(T$`XG"`U7L
MBT78BP"-!`(M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+5=R+1>`)T(G!(TWD
MBU7<BT7@(=`)R(T$`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!3>0"BT7L
MB<'!R1N+5>2+1>@QT#-%X(T$`8G"`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!
M3>@"BT7PB<'!R1N+5>B+1>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%
MW(-%V`3!3>P"BT7<B<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M
M*CZ=-8E%X(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78
MBP"-!`(M*CZ=-8E%Y(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"
M`U7LBT78BP"-!`(M*CZ=-8E%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%
MW(T$`8G"`U7PBT78BP"-!`(M*CZ=-8E%[(-%V`3!3>0"BT7LB<'!R1N+5>2+
M1>@QT#-%X(T$`8G"`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!3>@"BT7PB<'!
MR1N+5>B+1>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%V`3!3>P"
MBT7<B<'!R1N+5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=-8E%X(-%
MV`3!3?`"BT7@B<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(M*CZ=
M-8E%Y(-%V`3!3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78BP"-
M!`(M*CZ=-8E%Z(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"`U7P
MBT78BP"-!`(M*CZ=-8E%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%X(T$
M`8G"`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!3>@"BT7PB<'!R1N+5>B+1>PQ
MT#-%Y(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%V`3!3>P"BT7<B<'!R1N+
M5>R+1?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=-8E%X(-%V`3!3?`"BT7@
MB<'!R1N+5?"+1=PQT#-%[(T$`8G"`U7HBT78BP"-!`(M*CZ=-8E%Y(-%V`3!
M3=P"BT7DB<'!R1N+5=R+1>`QT#-%\(T$`8G"`U7LBT78BP"-!`(M*CZ=-8E%
MZ(-%V`3!3>`"BT7HB<'!R1N+5>"+1>0QT#-%W(T$`8G"`U7PBT78BP"-!`(M
M*CZ=-8E%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@QT#-%X(T$`8G"`U7<BT78
MBP"-!`(M*CZ=-8E%\(-%V`3!3>@"BT7PB<'!R1N+5>B+1>PQT#-%Y(T$`8G"
M`U7@BT78BP"-!`(M*CZ=-8E%W(-%V`3!3>P"BT4(BP")P@-5W(M%"(D0BT4(
MBT`$B<(#5?"+10B)4`2+10B+0`B)P@-5[(M%"(E0"(M%"(M`#(G"`U7HBT4(
MB5`,BT4(BT`0B<(#5>2+10B)4!"!Q'`!``!;7<-5B>6+10C'``$C16>+10C'
M0`2)J\WOBT4(QT`(_MRZF(M%",=`#'94,A"+10C'0!#PX=+#BT4(QT`4````
M`(M%",=`&`````"+10C'0%P`````7<-5B>6#[!B+10B+4!2+11#!X`.-!`*)
M1?B+10B+0!0[1?AV#XM%"(M`&(U0`8M%"(E0&(M5"(M%^(E"%(M%"(M0&(M%
M$,'H'0'"BT4(B5`8BT4(BT!<A<`/A)\```"+10B+4%RX0````"G0B47\BT7\
M.T40?@:+11")1?R+3?R+10B-4!R+10B+0%R-!`*#[`11_W4,4.C#W/__@\00
MBT7\*440BT7\`44,BT4(BT!<B<(#5?R+10B)4%R+10B+0%R#^$!U7_]U".@0
M[/__@\0$ZRJ+10B#P!R#[`1J0/]U#%#H=]S__X/$$(-%#$"#;1!`_W4(Z.3K
M__^#Q`2#?1`_?]"+51"+10B#P!R#[`12_W4,4.A%W/__@\00BU4(BT40B4)<
MR<-5B>7_=0SHK.O__X/$!(M%#(L`P>@8B,*+10B($(M%"(U0`8M%#(L`P>@0
MB`*+10B-4`*+10R+`,'H"(@"BT4(C5`#BT4,BP"(`HM%"(U0!(M%#(M`!,'H
M&(@"BT4(C5`%BT4,BT`$P>@0B`*+10B-4`:+10R+0`3!Z`B(`HM%"(U0!XM%
M#(M`!(@"BT4(C5`(BT4,BT`(P>@8B`*+10B-4`F+10R+0`C!Z!"(`HM%"(U0
M"HM%#(M`",'H"(@"BT4(C5`+BT4,BT`(B`*+10B-4`R+10R+0`S!Z!B(`HM%
M"(U0#8M%#(M`#,'H$(@"BT4(C5`.BT4,BT`,P>@(B`*+10B-4`^+10R+0`R(
M`HM%"(U0$(M%#(M`$,'H&(@"BT4(C5`1BT4,BT`0P>@0B`*+10B-4!*+10R+
M0!#!Z`B(`HM%"(U0$XM%#(M`$(@"R<-5B>6#[!B+10R+0!2)1?B+10R+0!B)
M1?2+1?C!Z`.#X#^)1?R+10R-4!R+1?R-!`+&`(#_1?R#??PX?DBX0````"M%
M_(G!BT4,C5`<BT7\C00"@^P$46H`4.A)V?__@\00_W4,Z/[I__^#Q`2+10R#
MP!R#[`1J.&H`4.@HV?__@\00ZR6X.````"M%_(G!BT4,C5`<BT7\C00"@^P$
M46H`4.@!V?__@\00BT7TP>@8B,*+10R(4%2+1?3!Z!"(PHM%#(A058M%],'H
M"(C"BT4,B%!6BT7TB,*+10R(4%>+1?C!Z!B(PHM%#(A06(M%^,'H$(C"BT4,
MB%!9BT7XP>@(B,*+10R(4%J+1?B(PHM%#(A06_]U#/]U".B2_?__@\0(R<-5
MB>6#[!C'1?P`````QT7X`````.@+VO__@^P,4.CBV?__@\00B47X@WWX`'0(
MBT7XBP")1?R+1?S)PU6)Y8/L"(/L#&H`Z'G;__^#Q!"+`(/L#%#H6]C__X/$
M$(/L#%#H?]K__X/$$(/L"%#_=0CHQ!<``(/$$(7`#X6)````@^P,:@#H.]O_
M_X/$$(L`@^P,4.@=V/__@\00@^P,4.A!VO__@\00BT`0)0#P```]`$```'0V
M@^P,:@#H!=O__X/$$(L`@^P,4.CGU___@\00@^P,4.@+VO__@\00BT`0)0#P
M```]`*```'4=@^P(:@+_=0CH+-C__X/$$(7`=0G'1?P!````ZP?'1?P`````
MBT7\R<-5B>575E.#[#S'1?``````QT7L`````(U%S(E%P,=%O%S:!`C'1;@&
M````BWW`BW6\BTVX\Z7'1>0`````QT7H`````.G$````@^P,_W7PZ)W=__^#
MQ!")1>R#?>P`=`F+1>R*`(3`=1:#[`C_=0C_=?#HE-W__X/$$.F+````@^P(
M_W4(_W7LZ-/8__^#Q!"%P'5V@^P,_W4(Z#'8__^#Q!")PZ%(404(@^P,4.@>
MV/__@\00`<.#[`S_=>SH#MC__X/$$(T$`X/``H/L#%#HG-C__X/$$(E%Y*%(
M404(@^P,_W7L4/]U"&A)V00(_W7DZ$K5__^#Q""#[`C_=>3_=?#H!-W__X/$
M$/]%Z(M%Z(M$A<R)1?"+1?"*`(3`#X4E____C67T6UY?7<-5B>575E.![#R!
M``"+10B)A=!^__]EH10```")1?`QP,>%1'___P````#'A4!___\`````QX4\
M?___`````,>%]'[__Z3:!`C'A?A^__^LV@0(QX7\?O__1]D$",>%`'___UK:
M!`B-E=Q^__^)E<A^___'A<1^__^,V@0(QX7`?O__!@```(N]R'[__XNUQ'[_
M_XN-P'[___.EQX4$?___L=H$",>%"'___[;:!`C'A0Q___]:V@0(QX4X?___
MO]H$",>%-'___UK:!`C'A3!___\`````QX4L?___`````,>%*'___P````#'
MA1A___\`````@^P,:#'9!`CHQ-O__X/$$(F%/'___X.]/'___P!T.8N%/'__
M_XH`A,!T+8/L#/^U/'___^BG_?__@\00@^P,_[4\?___Z#;8__^#Q!")A<Q^
M___I0P8``.AO_/__B84L?___@[TL?___`'5QQX5,?___`````.L]@^P,_[5`
M?___Z$O;__^#Q!")A3Q___^#O3Q___\`=!>#[`S_M3Q____HVM?__X/$$(F%
M+'____^%3'___X.]+'___P!U'XN%3'___XN$A01___^)A4!___^+A4!___^*
M`(3`=9N#O2Q___\`=0S'A2Q____$V@0(ZT^+A2Q___^)A4A____K->@KU?__
MBQ"+A4A___^*``^^P`'`C00"9HL`)?__``"#X`B%P'4)BX5(?___Q@!?_X5(
M?___BX5(?___B@"$P'6_QX5,?___`````.M2@^P,_[5`?___Z';:__^#Q!")
MA3Q___^#O3Q___\`="R#[`S_M3Q____HC/O__X/$$(7`=!>#[`S_M3Q____H
M\-;__X/$$(F%1'____^%3'___X.]1'___P!U'XN%3'___XN$A=Q^__^)A4!_
M__^+A4!___^*`(3`=8;'A4Q___\`````ZS*#[`S_M3Q____H)OO__X/$$(7`
M=!>#[`S_M3Q____HBM;__X/$$(F%1'____^%3'___X.]1'___P!U'XN%3'__
M_XN$A?1^__^)A3Q___^+A3Q___^*`(3`=::#[`S_M41____H==3__X/$$(G#
M@^P,_[4X?___Z&+4__^#Q!`!PX/L#/^U+'___^A/U/__@\00`<.#[`S_M31_
M___H/-3__X/$$(T$`P4`!```B848?___BX48?___@^P,4.B\U/__@\00B84H
M?___H411!0B#[`C_M2Q_____M3A___]0_[5$?___:,O:!`C_M2A____H6-'_
M_X/$((/L"&CM`0``_[4H?___Z'+1__^#Q!"#[`QH0]H$".CCV/__@\00B84\
M?___@^P,_[4\?___Z'O5__^#Q!")PHN%T'[__XL`@^P(4E#H9-S__X/$$(F%
M,'___X.],'___P!U#HN%T'[__XL`B84P?___Z'7B__^%P`^%)0(``(/L"&H`
M_[4P?___Z.?4__^#Q!")A21___^#O21___\`#X3_`0``:@)J_VKN_[4D?___
MZ)#1__^#Q!"#[`1J!HV%4'___U#_M21____H]M'__X/$$(J%4'___X3`#X6O
M````BH51?___/$,/A:$```"*A5)___\\00^%DP```(J%4W___SQ##X6%````
MBH54?___/$AU>XJ%57___SQ%=7%J`FK_:L;_M21____H%M'__X/$$(/L!&HI
MC850?___4/^U)'___^A\T?__@\00BQU$404(@^P,_[4H?___Z(72__^#Q!")
MP@.5*'___X/L#/^U-'___XV%4'___U!3:-3:!`A2Z,[/__^#Q"#I#@(``(V%
M4/___U#H>?3__X/$!.L?@^P$_[4@?___C850?___4(V%4/___U#HK/3__X/$
M$(/L!&@`@```C850?___4/^U)'___^CLT/__@\00B84@?___@[T@?___`'^U
M@^P,_[4D?___Z%S2__^#Q!"#[`B-A5#___]0C47<4.C/]O__@\00QX4<?___
M`````.LXBX4<?___BD0%W+D`````B,&+A1Q___\!P(G"C46S`="#[`11:.':
M!`A0Z`C/__^#Q!#_A1Q___^#O1Q___\3?K_&1=L`BQU$404(@^P,_[4H?___
MZ&[1__^#Q!")P@.5*'___X/L#/^U-'___XU%LU!3:-3:!`A2Z+K.__^#Q"#I
M^@```,>%%'___P````"#[`S_M2A____H*M'__X/$$(F%$'___X/L"&CXV00(
M:&S9!`CH2M;__X/$$.B7SO__B<.+-411!0B#[`S_M2A____H\=#__X/$$`.%
M*'___X/L#/^U-'___U-6:.;:!`A0Z$+.__^#Q"#K6HN5$'___XN%*'___P'0
MQ@``_X44?___Z$'.__^)PXLU1%$%"(/L#/^U*'___^B;T/__@\00`X4H?___
M@^P(_[4T?____[44?___4U9H\MH$"%#HYLW__X/$((/L"&CM`0``_[4H?___
MZ`#.__^#Q!"#^/]U$.BSS?__BP"#^!$/A'O___^#[`C_M2A___]H,=D$".AP
MU?__@\00@^P,_[4H?___Z%3W__^#Q!"+A2A___^)A<Q^__^+A<Q^__^+5?!E
M,Q44````=`7HOM#__XUE]%M>7UW#58GE4X/L=,=%\`````"#?0@`#X12`0``
MBT4(B@"$P`^$10$``(/L#/]U".@FS___@\00B47X@WWX``^$*@$``.GN````
MBT7T@\`3@^P(:$?9!`A0Z)W1__^#Q!"%P`^$SP```(M%](/`$X/L"&@!VP0(
M4.A^T?__@\00A<`/A+````"#[`S_=0CH:,___X/$$(G#BT7T@\`3@^P,4.A4
MS___@\00C00#@\`"B47LBT7L@^P,4.C<S___@\00B47PBT7T@\`34/]U"&@$
MVP0(_W7PZ(_,__^#Q!"#[`B-18Q0_W7PZ#$-``"#Q!"#^/]T'XM%G"4`\```
M/0!```!U$(/L#/]U\.CU_O__@\00ZPZ#[`S_=?#HZ\[__X/$$(/L#/]U\.C=
MS?__@\00QT7P`````(/L#/]U^.B(SO__@\00B47T@WWT``^%]_[__X/L#/]U
M^.C]SO__@\00@^P,_W4(Z%_/__^#Q!"+7?S)PU6)Y8/L&(/L#/]U".A;VO__
M@\00B47\_W7\Z!':__^#Q`2)1?CH8]W__X7`=#6#?0@`="^+10B*`(3`=":#
M[`AHO]H$"/]U^.C*SO__@\00.T7X=0Z#[`S_=0CH,?[__X/$$,G#58GE4X/L
M%(/L#&H`Z/'/__^#Q!"+`(/L#%#HT\S__X/$$(/L#%#H=\O__X/$$(L`BU@$
M@^P,:@#HQ<___X/$$(L`@^P,4.BGS/__@\00@^P,4.CKR___@\00B@"(0QB#
M[`QJ`.B9S___@\00BP"#[`Q0Z'O,__^#Q!"#[`Q0Z!_+__^#Q!"+`(M8!(/L
M#&H`Z&W/__^#Q!"+`(/L#%#H3\S__X/$$(/L#%#HH\O__X/$$(L`BT`0)?\!
M``!FB4,:@^P,:@#H.,___X/$$(L`@^P,4.@:S/__@\00@^P,4.B^RO__@\00
MBP"+6`2#[`QJ`.@,S___@\00BP"#[`Q0Z.[+__^#Q!"#[`1J`&A:V@0(4.AK
MSO__@\00B4,<@^P,:@#HV\[__X/$$(L`@^P,4.B]R___@\00@^P,4.AARO__
M@\00BP"+6`2#[`QJ`.BOSO__@\00BP"#[`Q0Z)'+__^#Q!"#[`Q0Z+7*__^#
MQ!"+`(E#((/L#&H`Z(/.__^#Q!"+`(/L#%#H9<O__X/$$(/L#%#H"<K__X/$
M$(L`BT`$B47T@^P,:@#H5,[__X/$$(L`@^P,4.@VR___@\00@^P,4.A*S?__
M@\00BP"%P'0Q@^P,:@#H)\[__X/$$(L`@^P,4.@)R___@\00@^P,4.@=S?__
M@\00BP"+0&R)1?CK!\=%^`````"+5?B+1?2)4"2#[`QJ`.CFS?__@\00BP"#
M[`Q0Z,C*__^#Q!"#[`Q0Z&S)__^#Q!"+`(M`!,=`*`````"#[`QJ`.BSS?__
M@\00BP"#[`Q0Z)7*__^#Q!"#[`Q0Z#G)__^#Q!"+`(M`!,=`+`````"#[`QJ
M`.B`S?__@\00BP"#[`Q0Z&+*__^#Q!"#[`Q0Z`;)__^#Q!"+`(M8!(/L#&H`
MZ%3-__^#Q!"+`(/L#%#H-LK__X/$$(/L#%#H^LS__X/$$(L`B4,PBUW\R<-5
MB>6#[`B#[`QJ`.@=S?__@\00BP"#[`Q0Z/_)__^#Q!"#[`AJ_U#H0<K__X/$
M$(/L#&H`Z/3,__^#Q!"+`(/L#%#HULG__X/$$(/L!&H`:.K+!`A0Z"/-__^#
MQ!#)PU6)Y593@^PPQT7@`````(/L#&H`Z+7,__^#Q!"+`(/L#%#HE\G__X/$
M$(/L#%#H"\K__X/$$,8``8/L#&A0V00(Z,G/__^#Q!")1=R#?=P`=!.+1=R*
M`#PQ=0J+1=Q`B@"$P'0%Z)77__^#[`QJ`.A:S/__@\00BP"#[`Q0Z#S)__^#
MQ!!J"VH!:`K;!`A0Z.K(__^#Q!")1?2#??0`#X0J`0``BT7TBT`,BT`8B47P
MQT7D`0```.FV````BT7DC5C_@^P,:@#H`LS__X/$$(L`@^P,4.CDR/__@\00
M:@!3_W7P4.A5RO__@\00B47L@WWL``^$AP```(M%[(L`BT`()0`$``"%P'0-
MBT7LBP"+0`R)1<CK,8M%[(L8@^P,:@#HJ,O__X/$$(L`@^P,4.B*R/__@\00
M:@)J`%-0Z.S+__^#Q!")1<B+%:QA!0B+1>3!X`*-!`*+`(/L"/]UR%#HB<O_
M_X/$$(7`=13_1>#_1>2AJ&$%"#E%Y`^,//___Z&H804(2#M%X'5#QT7D`0``
M`.LP@^P,:@#H,,O__X/$$(L`@^P,4.@2R/__@\00@^P(_W7P4.BSQ___@\00
MB47H_T7DH:AA!0@Y1>1\QH/L#&H`Z/;*__^#Q!"+`(/L#%#HV,?__X/$$&H%
M:@%H#]L$"%#HAL?__X/$$(E%](-]]`!T>8M%](M`#(L8@^P,:@#HN,K__X/$
M$(L`@^P,4.B:Q___@\00@^P$:!';!`A34.AHQ___@\00BT7TBT`,BP"+0`@E
M``!``(7`=#"+1?2+0`R+&(/L#&H`Z&_*__^#Q!"+`(/L#%#H4<?__X/$$(/L
M"%-0Z"3)__^#Q!"#[`QJ`.A'RO__@\00BP"#[`Q0Z"G'__^#Q!!J!6H!:!;;
M!`A0Z-?&__^#Q!")1?2#??0`#X2-````QT78`````(/L#&@ZV00(Z$3-__^#
MQ!")1=B#?=@`=#6+1?2+0`R+&(/L#&H`Z.7)__^#Q!"+`(/L#%#HQ\;__X/$
M$(/L!/]UV%-0Z)?&__^#Q!#K.*&L804(BQB+1?2+0`R+,(/L#&H`Z*G)__^#
MQ!"+`(/L#%#HB\;__X/$$(/L!%-64.CYRO__@\00@^P,:@#H@,G__X/$$(L`
M@^P,4.ABQO__@\00@^P,4.C6QO__@\00Q@``@^P,:@#H5LG__X/$$(L`@^P,
M4.@XQO__@\00@^P,4.ALR?__@\00QP``````@^P,:#'9!`CH9\S__X/$$*.D
M804(H:1A!0B%P`^%^@```*&L804(@^P,4.A_[___@\00HZ1A!0BAK&$%"(E%
MS(M%](M`#(L`BT`()0`$``"%P'00BT7TBT`,BP"+0`R)1=#K-(M%](M`#(L8
M@^P,:@#HO<C__X/$$(L`@^P,4.B?Q?__@\00:@)J`%-0Z`')__^#Q!")1="#
M[`C_=<S_==#HG<;__X/$$(E%Y(M%](M`#(L`BT`()0`$``"%P'00BT7TBT`,
MBP"+0`R)1=3K-(M%](M`#(L8@^P,:@#H4<C__X/$$(L`@^P,4.@SQ?__@\00
M:@)J`%-0Z)7(__^#Q!")1=2AK&$%"(L`_W7D_W744&@8VP0(Z&?'__^AI&$%
M"(/L"&CM`0``4.C$P___@\00B47D@WWD`'0H@WWD$70B@WWD_W0<H:1A!0B+
M%:QA!0B+$O]UY%!2:$C;!`CH(,?__XUE^%M>7<-5B>6#[`B#[`QJ`.BYQ___
M@\00BP"#[`Q0Z)O$__^#Q!"#[`Q0Z,O(__^#Q!"#[`QJ`.B2Q___@\00BP"#
M[`Q0Z'3$__^#Q!"#[`AJ`&A:V@0(:%K:!`AH'L\$"&B6VP0(4.@RQ?__@\0@
MR<.-3"0$@^3P_W'\58GE48/L%(E-Z(/L!(M%Z(/`"%"+1>B#P`10_W7HZ!#'
M__^#Q!"#[`1HW)<$"&C<EP0(:*R9!`CHN@(``(/$$(/L#&H`Z"G$__^#Q!"*
M`(3`=5CH"\3__Z.@804(H:!A!0B%P'4*@^P,:@'H(\?__Z&@804(@^P,4.BU
MQ/__@\00@^P,:@#HR,;__X/$$(L`@^P,4.BJP___@\00@^P,4.@.QO__@\00
MQ@``@^P,:@#HGL;__X/$$(L`@^P,4.B`P___@\00@^P,4.B4QO__@\00B<**
M`H/(`H@"@^P,:@#H;L;__X/$$(L`@^P,4.A0P___@\00@^P,4.ADQO__@\00
MB<**`H/(`8@"BU7HBP*#P`6Z`````%)0WRPDC60D"-GNWL'=!;C;!`C9R=_I
MW=@/E\"#\`&$P'4-@^P,:&11!0CH6\7__XM-Z(L!@\`%P>`"@^P,4.AGQ?__
M@\00HZQA!0B+%:QA!0B+3>B+002+`(D"H:QA!0B#P`3'`*O;!`BAK&$%"(/`
M",<`X-L$",<%J&$%"`,```"+%:QA!0BAJ&$%",'@`HT$`L<`KML$"*&H804(
M0*.H804(QT7T`0```.LTBPVL804(H:AA!0@#1?2)PK@!````*=#!X`+WV`'!
MBT7HBU`$BT7TP>`"C00"BP")`?]%](M5Z(L".47T?,*+#:QA!0B+1>B+$*&H
M804(C00"B<*X`0```"G0P>`"]]B-!`''``````"+#:QA!0B+1>B+$*&H804(
MC00"2(L5H&$%"(/L#&H`45!H(]0$"%+HVL#__X/$((E%^(-]^`!U%*&@804(
M@^P,4.APP?__@\00B47XH:!A!0B#[`Q0Z&S#__^#Q!"#[`QH8-D$".C]Q___
M@\00A<!U.*&D804(A<!U%8/L#&@QV00(Z.#'__^#Q!"CI&$%"*&D804(A<!T
M$:&D804(@^P,4.@9]/__@\00H:!A!0B#[`Q0Z#_`__^#Q!#H]\'__XM%^(M-
M_,F-8?S#58GE4^@`````6X'#6W@``(N#3`$``(M-$%"+50R+10A14E#HI,#_
M_XM=_,G#D)"058GE7<.-="8`C;PG`````%6)Y5=64X/L#.@`````6X'#%G@`
M`.A"O___C8/P_O__C9/P_O__*=")Q\'_`G0E,?:-M"8`````BTT04(M5#(M%
M"%%24/^4L_#^__]&@\00.?YRY(UE]%M>7UW#D)"0D%6)Y5/H`````%N!P[MW
M``"+50R+10A24&H#Z,V___^+7?S)PY"0D)"0D)"0D)"0D%6)Y5/H`````%N!
MPXMW``"+50R+10A24&H#Z+W`__^+7?S)PY"0D)"0D)"0D)"0D%6)Y5.#[`2A
MY$X%"(/X_W03N^1.!0AFD(/K!/_0BP.#^/]U]%A;7<-5B>53@^P$Z`````!;
M@<,P=P``Z,##__]96\G#`````````````````P````$``@!P97)L>'-I+F,`
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`"]P<F]C+W-E;&8O97AE`"\`
M.@!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`"X`)7,E
M<R5S`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"
M04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$```!?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```3$1?3$E"4D%265]0051(
M`$Q)0E!!5$@`3$E"4D%265]0051(`%!!5$@`1%E,1%],24)205)97U!!5$@`
M```>V@0(+MH$"#;:!`A#V@0(2-H$"%K:!`A435!$25(`5$5-4$1)4@!414U0
M`%1-4`#!V00(=-H$"'O:!`B#V@0(B-H$"%K:!`A#.EQ414U0`"]T;7``55-%
M4@!54T523D%-10!P87(M`%-94U1%30`E<R5S)7,E<P`E<V-A8VAE+25S)7,`
M)3`R>``E<W1E;7`M)74E<P`E<W1E;7`M)74M)74E<P`N+@`E<R\E<P!!4D=6
M`!@`<&5R;``P`"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I
M;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R
M>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*
M`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"UE`"TM`````````````(#____/07!A
M<BYP;```````````````````````````````````(R$O=7-R+V)I;B]P97)L
M"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C
M:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S
M92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC
M=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I
M<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@
M("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R
M96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@
M;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@
M("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@
M("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E
M;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@
M:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@
M<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H
M870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@
M("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R
M(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A
M;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S
M('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@
M=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@
M("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@
M("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@
M,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R
M7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@
M("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@
M("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@
M("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@
M("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I
M.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A
M;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%2
M1U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA
M<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M
M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@
M9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@
M+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051(
M"FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@
M("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD
M;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H
M96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*
M("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN
M;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@
M97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X
M=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E
M<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@
M)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA
M;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E
M;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[
M"B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A
M;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S
M:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@
M)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@
M("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@
M("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT
M("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L
M"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@
M(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@
M("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K
M97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@
M>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\[
M"B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@
M9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*
M"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*
M("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U
M<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE
M+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U
M="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG
M+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE
M9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P
M<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!0
M05(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E
M<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*
M("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C
M(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@
M("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@
M("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C
M=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@
M("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@
M("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC
M($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L;&]W(&%R
M9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A
M<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@
M<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A
M;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@
M<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("!M
M>2!`861D7W1O7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@<'5S:"!`
M861D7W1O7VEN8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H
M:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D
M,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD
M;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE
M="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*
M("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS
M:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L
M971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D[
M"B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@
M("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U
M<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[
M>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII
M<#L*("`@('T*"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY
M("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@
M(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@
M;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U
M="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@
M("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD[
M"B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H
M)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@
M("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@
M("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@
M("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N
M9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L
M("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D
M<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@
M)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@
M("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@
M("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M
M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@<F5Q=6ER95]M
M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@
M("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@
M("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@
M("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@
M("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U](&5Q("=<
M7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@;7D@)69I;&5S
M.PH@("`@("`@("]>7SPH+BLI)"\@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O
M+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@
M("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R
M+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D
M97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L
M93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S
M.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E
M(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2
M.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@
M("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I
M;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@
M(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PI]"@HC
M(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O
M;6MT;7!D:7(N8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@
M("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@
M("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@
M("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@
M("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S
M97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@
M("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@
M("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*
M("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@
M("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O
M<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y
M"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@
M("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT
M+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F
M:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I
M.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S971?<')O
M9VYA;64@>PH@("`@:68@*"1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]
M("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@
M("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G
M;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI
M;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@
M7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K
M('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@
M>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@
M("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]4
M14U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]
M"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS
M=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F
M:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E
M;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET
M7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@
M("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*
M?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C
M:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PH*,3L*"B-L:6YE(#DY,PH*7U]%3D1?7PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/__
M__\`````_____P```````````0````$````!````L@(```$```"]`@```0``
M`,<"```!````%@,```$```!)!```#````"R7!`@-````N-@$"`0```!H@00(
M]?[_;\"$!`@%````2(T$"`8````8A@0("@```-T%```+````$````!4`````
M`````P```/1/!0@"````>`(``!0````1````%P```+24!`@1````G)0$"!(`
M```8````$P````@```#^__]O#)0$"/___V\"````\/__;R:3!`@`````````
M````````````````````````````````````````````````````````````
M^$X%"```````````<I<$"(*7!`B2EP0(HI<$"+*7!`C"EP0(TI<$".*7!`CR
MEP0(`I@$"!*8!`@BF`0(,I@$"$*8!`A2F`0(8I@$"'*8!`B"F`0(DI@$"**8
M!`BRF`0(PI@$"-*8!`CBF`0(\I@$"`*9!`@2F00((ID$"#*9!`A"F00(4ID$
M"&*9!`ARF00(@ID$")*9!`BBF00(LID$",*9!`C2F00(XID$"/*9!`@"F@0(
M$IH$""*:!`@RF@0(0IH$"%*:!`ABF@0(<IH$"(*:!`B2F@0(HIH$"+*:!`C"
MF@0(TIH$".*:!`CRF@0(`IL$"!*;!`@BFP0(,IL$"$*;!`A2FP0(8IL$"'*;
M!`B"FP0(DIL$"**;!`BRFP0(PIL$"-*;!`CBFP0(\IL$"`*<!`@2G`0((IP$
M"#*<!`A"G`0(4IP$"```````````'=D$"!_9!`C_____P-L$"%Q7````1T-#
M.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U
M(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U
M8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T
M+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#
M.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U
M(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U
M8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T
M+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#
M.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N8W1O<G,`
M+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M````````"P````$````"````-($$"#0!```3```````````````!````````
M`!,````'`````@```$B!!`A(`0``(```````````````!``````````E````
M!0````(```!H@00(:`$``%@#```%``````````0````$````(0```/;__V\"
M````P(0$",`$``!8`0``!0`````````$````!````"L````+`````@```!B&
M!`@8!@``,`<```8````!````!````!`````S`````P````(```!(C00(2`T`
M`-T%``````````````$`````````.P```/___V\"````)I,$""83``#F````
M!0`````````"`````@```$@```#^__]O`@````R4!`@,%```D`````8````"
M````!`````````!7````"0````(```"<E`0(G!0``!@````%``````````0`
M```(````8`````D````"````M)0$"+04``!X`@``!0````P````$````"```
M`&D````!````!@```"R7!`@L%P``,```````````````!`````````!D````
M`0````8```!<EP0(7!<````%``````````````0````$````;P````$````&
M````8)P$"&`<``!8/``````````````0`````````'4````!````!@```+C8
M!`BX6```'```````````````!`````````![`````0````(```#@V`0(X%@`
M`%U:`````````````"``````````@P````$````"````0#,%"$"S```$````
M```````````$`````````(T````!`````P```.1.!0CDO@``"```````````
M````!`````````"4`````0````,```#L3@4([+X```@```````````````0`
M````````FP````$````#````]$X%"/2^```$```````````````$````````
M`*`````&`````P```/A.!0CXO@``^`````8`````````!`````@```"I````
M`0````,```#P3P4(\+\```0```````````````0````$````K@````$````#
M````]$\%"/2_``!(`0`````````````$````!````+<````!`````P```#Q1
M!0@\P0``'```````````````!`````````"]````"`````,```!@404(6,$`
M`%`0`````````````"``````````P@````$``````````````%C!``",`0``
M```````````!``````````$````#``````````````#DP@``RP``````````
+`````0``````````
